"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http = require("http");
const fs = require("fs-extra");
const log_formatter_1 = require("log-formatter");
const NodeServicesManager_1 = require("./../Node/NodeServicesManager");
/**
 * NodeServicesManager的基础上添加的功docker进行健康检查的服务器。
 * 服务器监听在 /tmp/service_starter_health_checking.sock
 */
class DockerServicesManager extends NodeServicesManager_1.NodeServicesManager {
    constructor(_config = {}) {
        super(_config);
        if (_config.startHealthChecking !== false && process.platform === 'linux') { // 配置健康检查服务
            // 要被监听的端口
            const port = '/tmp/service_starter_health_checking.sock';
            // 删除之前的端口，避免被占用
            fs.removeSync(port);
            // 创建服务器
            const server = http.createServer(async (req, res) => {
                const result = await this.healthCheck();
                res.end(result.description);
            });
            server.once('error', err => {
                log_formatter_1.default.error
                    .location.white
                    .title.red
                    .content.red(this.name, '健康检查服务器出现异常：', err);
            });
            server.listen(port);
        }
    }
}
exports.DockerServicesManager = DockerServicesManager;
