import { BaseServiceModule } from './BaseServiceModule';
import { BaseServicesManager } from './BaseServicesManager';
/**
 * 对于注册服务的生命周期进行管理。
 * 对注册了的服务进行一层封装，便于ServicesManager使用。
 */
export declare class RegisteredService {
    /**
     * 保存对服务管理器的引用
     */
    private readonly _manager;
    /**
     * 服务实例
     */
    readonly service: BaseServiceModule;
    constructor(service: BaseServiceModule, manager: BaseServicesManager);
    /**
     * 绑定在服务模块上的错误监听器
     */
    private readonly _errorListener;
    /**
     * 启动服务。成功返回void，失败返回Error。
     * 如果抛出异常则一定是service-starter的逻辑错误
     * 这个方法仅供内部使用。
     */
    start(): Promise<Error | void>;
    /**
     * 停止服务。
     * 如果抛出异常则一定是service-starter的逻辑错误
     * 这个方法仅供内部使用。
     */
    stop(): Promise<void>;
    /**
     * 健康检查。
     * 如果抛出异常则一定是service-starter的逻辑错误
     * 这个方法仅供内部使用。
     */
    healthCheck(): Promise<Error | void>;
}
